@@ -345,7 +345,7 @@ int __glXSwapUseXFont(__GLXclientState *cl, GLbyte *pc)
 
 int __glXSwapQueryExtensionsString(__GLXclientState *cl, GLbyte *pc)
 {
-    xGLXQueryExtensionsStringReq *req = NULL;
+    xGLXQueryExtensionsStringReq *req = (xGLXQueryExtensionsStringReq *)pc;
     __GLX_DECLARE_SWAP_VARIABLES;
 
     __GLX_SWAP_SHORT(&req->length);
