@@ -33,6 +33,8 @@ in this Software without prior written authorization from The Open Group.
 #include <dix-config.h>
 #endif
 
+#include <stdlib.h>
+
 #include <X11/X.h>
 #include <X11/Xproto.h>
 #include "misc.h"
@@ -48,9 +50,6 @@ in this Software without prior written authorization from The Open Group.
 #include <X11/extensions/shapestr.h>
 #include "regionstr.h"
 #include "gcstruct.h"
-#ifdef EXTMODULE
-#include "xf86_ansic.h"
-#endif
 #include "modinit.h"
 
 typedef	RegionPtr (*CreateDftPtr)(
