@@ -52,10 +52,6 @@ SOFTWARE.
    written by drewry, september 1986
 */
 
-#ifdef HAVE_DIX_CONFIG_H
-#include <dix-config.h>
-#endif
-
 #include "pixmap.h"
 #include "region.h"
 #include "gc.h"
@@ -1129,8 +1125,3 @@ typedef struct _afbpos{
 #define MFB_EQWHOLEWORD_INVERT	^=~0
 #define MFB_OP_WHITE					/* nothing */
 #define MFB_OP_BLACK					~
-
-#ifdef XFree86LOADER
-#include "xf86_ansic.h"
-#endif
-
