@@ -1,5 +1,5 @@
 /*
- * $Id: compext.c,v 1.5 2005/07/03 07:37:34 daniels Exp $
+ * $Id$
  *
  *
  * Copyright © 2006 Sun Microsystems
@@ -501,7 +501,7 @@ ProcCompositeReleaseOverlayWindow (ClientPtr client)
 	return BadMatch;
     }
 
-    deleteCompOverlayClient(pOc, pOc->pScreen);
+    FreeResource(pOc->resource, 0);
 
     cs = GetCompScreen(pScreen);
     if (cs->pOverlayClients == NULL) {
